Module: FunWith::Gems::Testing::GemToTestMethods::ClassMethods
- Defined in:
- lib/fun_with/gems/testing/gem_to_test_methods.rb
Instance Attribute Summary collapse
-
#gem_to_test ⇒ Object
What FunWith::Gems - derived gem is being tested? check as far up the class tree as needed.
Instance Attribute Details
#gem_to_test ⇒ Object
What FunWith::Gems - derived gem is being tested? check as far up the class tree as needed.
15 16 17 18 19 20 |
# File 'lib/fun_with/gems/testing/gem_to_test_methods.rb', line 15 def gem_to_test @gem_to_test ||= nil rval = @gem_to_test rval = self.superclass.gem_to_test if !rval && self.superclass.respond_to?( :gem_to_test ) rval end |